OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Kan ikke skrive i \"config\"-mappen!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan vanligvis ordnes ved å gi web-tjeneren skrivetilgang til config-mappen",
    "See %s" : "Se %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Dette kan vanligvis ordnes ved %så gi web-tjeneren skrivetilgang til config-mappen%s.",
    "Sample configuration detected" : "Eksempelkonfigurasjon oppdaget",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Det ble oppdaget at eksempelkonfigurasjonen er blitt kopiert. Dette kan ødelegge installasjonen din og støttes ikke. Les dokumentasjonen før du gjør endringer i config.php",
    "PHP %s or higher is required." : "PHP %s eller nyere kreves.",
    "PHP with a version lower than %s is required." : "PHP med en versjon lavere enn %s kreves.",
    "%sbit or higher PHP required." : "%sbit eller høyere PHP kreves",
    "Following databases are supported: %s" : "Følgende databaser støttes: %s",
    "The command line tool %s could not be found" : "Kommandolinjeverktøyet %s ble ikke funnet",
    "The library %s is not available." : "Biblioteket %s er ikke tilgjengelig.",
    "Library %s with a version higher than %s is required - available version %s." : "Bibliotek %s med en versjon høyere enn %s kreves - tilgjengelig versjon %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Bibliotek %s med en versjon lavere nn %s kreves - tilgjengelig version %s.",
    "Following platforms are supported: %s" : "Følgende plattformer støttes: %s",
    "Server version %s or higher is required." : "Tjenerversjon %s eller høyere kreves.",
    "Server version %s or lower is required." : "Tjenerversjon %s eller lavere kreves.",
    "Unknown filetype" : "Ukjent filtype",
    "Invalid image" : "Ugyldig bilde",
    "today" : "i dag",
    "yesterday" : "i går",
    "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dager siden"],
    "last month" : "forrige måned",
    "_%n month ago_::_%n months ago_" : ["for %n måned siden","for %n måneder siden"],
    "last year" : "forrige år",
    "_%n year ago_::_%n years ago_" : ["%n år siden","%n år siden"],
    "_%n hour ago_::_%n hours ago_" : ["for %n time siden","for %n timer siden"],
    "_%n minute ago_::_%n minutes ago_" : ["for %n minutt siden","for %n minutter siden"],
    "seconds ago" : "for få sekunder siden",
    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modul med id: %s eksisterer ikke. Aktiver den i app-innstillingene eller kontakt en administrator.",
    "File name is a reserved word" : "Filnavnet er et reservert ord",
    "File name contains at least one invalid character" : "Filnavnet inneholder minst ett ulovlig tegn",
    "File name is too long" : "Filnavnet er for langt",
    "Dot files are not allowed" : "Punktum-filer er ikke tillatt",
    "Empty filename is not allowed" : "Tomt filnavn er ikke tillatt",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Server settings" : "Tjenerinnstillinger",
    "Sharing" : "Deling",
    "Encryption" : "Kryptering",
    "Additional settings" : "Flere innstillinger",
    "Tips & tricks" : "Tips og triks",
    "%s enter the database username and name." : "%s legg inn database brukernavn og navn.",
    "%s enter the database username." : "%s legg inn brukernavn for databasen.",
    "%s enter the database name." : "%s legg inn navnet på databasen.",
    "%s you may not use dots in the database name" : "%s du kan ikke bruke punktum i databasenavnet",
    "Oracle connection could not be established" : "Klarte ikke å etablere forbindelse til Oracle",
    "Oracle username and/or password not valid" : "Oracle-brukernavn og/eller passord er ikke gyldig",
    "DB Error: \"%s\"" : "Databasefeil: \"%s\"",
    "Offending command was: \"%s\"" : "Kommandoen som feilet: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Du må legge inn enten en eksisterende konto eller administratoren.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Kommando som feilet: \"%s\", navn: %s, passord: %s",
    "PostgreSQL username and/or password not valid" : "PostgreSQL-brukernavn og/eller passord er ikke gyldig",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X støttes ikke og %s vil ikke fungere korrekt på denne plattformen. Bruk på egen risiko!",
    "For the best results, please consider using a GNU/Linux server instead." : "For beste resultat, vurder å bruke en GNU/Linux-tjener i stedet.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ut for at %s-instansen kjører i et 32-bit PHP-miljø med open_basedir konfigurert i php.ini. Dette vil føre til problemer med filer over 4 GB og frarådes på det sterkeste.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Vennligst fjern innstillingen open_basedir i php.ini eller bytt til 64-bit PHP.",
    "Set an admin username." : "Sett et admin-brukernavn.",
    "Set an admin password." : "Sett et admin-passord.",
    "Can't create or write into the data directory %s" : "Kan ikke opprette eller skrive i datamappen %s",
    "Invalid Federated Cloud ID" : "Ugyldig ID for sammenknyttet sky",
    "%s shared »%s« with you" : "%s delte »%s« med deg",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling av %s feilet, fordi serveren ikke tillater delinger fra type %i",
    "Sharing %s failed, because the file does not exist" : "Deling av %s feilet, fordi filen ikke eksisterer",
    "You are not allowed to share %s" : "Du har ikke lov til å dele %s",
    "Sharing %s failed, because you can not share with yourself" : "Deling av %s feilet fordi du ikke kan dele med deg selv",
    "Sharing %s failed, because the user %s does not exist" : "Deling av %s feilet, fordi brukeren %s ikke finnes",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Deling av %s feilet, fordi brukeren %s ikke er medlem av noen grupper som %s er medlem av",
    "Sharing %s failed, because this item is already shared with %s" : "Deling av %s feilet, fordi dette elementet allerede er delt med %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Deling av %s feilet, fordi dette elementet allerede er delt med bruker %s",
    "Sharing %s failed, because the group %s does not exist" : "Deling av %s feilet, fordi gruppen %s ikke finnes",
    "Sharing %s failed, because %s is not a member of the group %s" : "Deling av %s feilet, fordi %s ikke er medlem av gruppen %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Du må oppgi et passord for å lage en offentlig lenke. Bare beskyttede lenker er tillatt",
    "Sharing %s failed, because sharing with links is not allowed" : "Deling av %s feilet, fordi deling med lenker ikke er tillatt",
    "Not allowed to create a federated share with the same user" : "Ikke tillatt å opprette en Sammenknyttet sky-deling med den samme brukeren",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling %s feilet, fant ikke %s, kanskje tjeneren er utilgjengelig for øyeblikket.",
    "Share type %s is not valid for %s" : "Delingstype %s er ikke gyldig for %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Setting av tillatelser for %s feilet, fordi tillatelsene gikk ut over tillatelsene som er gitt til %s",
    "Setting permissions for %s failed, because the item was not found" : "Setting av tillatelser for %s feilet, fordi elementet ikke ble funnet",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan ikke sette utøpsdato. Delinger kan ikke utløpe senere enn %s etter at de har blitt delt",
    "Cannot set expiration date. Expiration date is in the past" : "Kan ikke sette utløpsdato. Utløpsdato er tilbake i tid",
    "Cannot clear expiration date. Shares are required to have an expiration date." : "Kan ikke fjerne utløpsdato. Delinger må ha en utløpsdato.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delings-server %s må implementere grensesnittet OCP\\Share_Backend",
    "Sharing backend %s not found" : "Delings-server %s ikke funnet",
    "Sharing backend for %s not found" : "Delings-server for %s ikke funnet",
    "Sharing failed, because the user %s is the original sharer" : "Deling feilet fordi brukeren %s er den som delte opprinnelig",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deling av %s feilet, fordi tillatelsene går utover tillatelsene som er gitt til %s",
    "Sharing %s failed, because resharing is not allowed" : "Deling av %s feilet, fordi videre-deling ikke er tillatt",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling av %s feilet, fordi delings-serveren for %s ikke kunne finne kilden",
    "Sharing %s failed, because the file could not be found in the file cache" : "Deling av %s feilet, fordi filen ikke ble funnet i fil-mellomlageret",
    "Cannot increase permissions of %s" : "Kan ikke øke tillatelser for %s",
    "Files can't be shared with delete permissions" : "Filer kan ikke deles med rettigheter til sletting",
    "Files can't be shared with create permissions" : "Filer kan ikke deles med rettigheter til å opprette",
    "Expiration date is in the past" : "Utløpsdato er tilbake i tid",
    "Cannot set expiration date more than %s days in the future" : "Kan ikke sette utløpsdato mer enn  %s dager fram i tid",
    "Could not find category \"%s\"" : "Kunne ikke finne kategori \"%s\"",
    "Sunday" : "Søndag",
    "Monday" : "Mandag",
    "Tuesday" : "Tirsdag",
    "Wednesday" : "Onsdag",
    "Thursday" : "Torsdag",
    "Friday" : "Fredag",
    "Saturday" : "Lørdag",
    "Sun." : "Søn.",
    "Mon." : "Man.",
    "Tue." : "Tir.",
    "Wed." : "Ons.",
    "Thu." : "Tirs.",
    "Fri." : "Fre.",
    "Sat." : "Lør.",
    "Su" : "Sø",
    "Mo" : "Ma",
    "Tu" : "Ti",
    "We" : "On",
    "Th" : "To",
    "Fr" : "Fr",
    "Sa" : "Lø",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "Mars",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Desember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Apps" : "Apper",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Bare disse tegnene tillates i et brukernavn: \"a-z\", \"A-Z\", \"0-9\" og \"_.@-'\"",
    "A valid username must be provided" : "Oppgi et gyldig brukernavn",
    "Username contains whitespace at the beginning or at the end" : "Brukernavn inneholder blanke på begynnelsen eller slutten",
    "A valid password must be provided" : "Oppgi et gyldig passord",
    "The username is already being used" : "Brukernavnet er allerede i bruk",
    "Login canceled by app" : "Innlogging avbrutt av app",
    "User disabled" : "Brukeren er deaktivert",
    "Help" : "Hjelp",
    "Personal" : "Personlig",
    "Users" : "Brukere",
    "Admin" : "Admin",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Appen \"%s\" kan ikke installeres på grunn av at appinfo filen ikke kan leses.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan ikke installere fordi den ikke er kompatibel med denne tjenerversjonen.",
    "No app name specified" : "Intet app-navn spesifisert",
    "App '%s' could not be installed!" : "Appen '%s' kunne ikke installeres!",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" kan ikke installeres fordi følgende avhengigheter ikke er tilfredsstilt: %s",
    "a safe home for all your data" : "et sikkert hjem for alle dine data",
    "File is currently busy, please try again later" : "Filen er opptatt for øyeblikket, prøv igjen senere",
    "Can't read file" : "Kan ikke lese fil",
    "Application is not enabled" : "Applikasjon er ikke påslått",
    "Authentication error" : "Autentikasjonsfeil",
    "Token expired. Please reload page." : "Symbol utløpt. Vennligst last inn siden på nytt.",
    "Unknown user" : "Ukjent bruker",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen databasedrivere (sqlite, mysql, or postgresql) installert.",
    "Cannot write into \"config\" directory" : "Kan ikke skrive i \"config\"-mappen",
    "Cannot write into \"apps\" directory" : "Kan ikke skrive i \"apps\"-mappen",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dette kan vanligvis ordnes ved %så gi web-tjeneren skrivetilgang til apps-mappen%s eller ved å deaktivere app-butikken i config-filen.",
    "Cannot create \"data\" directory (%s)" : "Kan ikke opprette \"data\"-mappen (%s)",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Dette fikses vanligvis ved å <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">gi webtjeneren skrivetilgang til rotmappen</a>.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Tillatelser kan vanligvis ordnes ved %så gi webtjeneren skrivetilgang til rotmappen%s.",
    "Setting locale to %s failed" : "Setting av nasjonale innstillinger til %s feilet.",
    "Please install one of these locales on your system and restart your webserver." : "Vennligst installer en av disse nasjonale innstillingene på systemet ditt og start webtjeneren på nytt.",
    "Please ask your server administrator to install the module." : "Be tjener-administratoren om å installere modulen.",
    "PHP module %s not installed." : "PHP-modul %s er ikke installert.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-innstilling \"%s\" er ikke satt til \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Ved å endre denne innstillingen i php.ini gjør at Nextcloud vil kjøre igjen.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload er satt til \"%s\" i stedet for den forventede verdien \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Sett <code>mbstring.func_overload</code> til <code>0</code> in php.ini for å fikse dette problemet",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Krever minst libxml2 2.7.0. Per nå er %s installert.",
    "To fix this issue update your libxml2 version and restart your web server." : "For å fikse dette problemet, oppdater din libxml2 versjon og omstart webtjeneren.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Det ser ut for at PHP er satt opp til å fjerne innebygde doc blocks. Dette gjør at flere av kjerneapplikasjonene blir utilgjengelige.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette forårsakes sannsynligvis av en bufrer/akselerator, som f.eks. Zend OPcache eller eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduler har blitt installert, men de listes fortsatt som fraværende?",
    "Please ask your server administrator to restart the web server." : "Be tjener-administratoren om å starte webtjeneren på nytt.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kreves",
    "Please upgrade your database version" : "Vennligst oppgrader versjonen av databasen din",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Endre tillatelsene til 0770 slik at mappen ikke kan listes av andre brukere.",
    "Data directory (%s) is readable by other users" : "Data-mappen (%s) kan leses av andre brukere",
    "Data directory (%s) must be an absolute path" : "Datamappen (%s) må være en absolutt sti",
    "Check the value of \"datadirectory\" in your configuration" : "Sjekk verdien for \"datadirectory\" i konfigurasjonen din",
    "Data directory (%s) is invalid" : "Data-mappe (%s) er ugyldig",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Sjekk at det ligger en fil \".ocdata\" i roten av data-mappen.",
    "Could not obtain lock type %d on \"%s\"." : "Klarte ikke å låse med type %d på \"%s\".",
    "Storage unauthorized. %s" : "Lager uautorisert: %s",
    "Storage incomplete configuration. %s" : "Ikke komplett oppsett for lager. %s",
    "Storage connection error. %s" : "Tilkoblingsfeil for lager. %s",
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Storage connection timeout. %s" : "Tidsavbrudd ved tilkobling av lager: %s",
    "4-byte characters are not supported in file names" : "4-byte tegn er ikke tillatt i filnavn",
    "App directory already exists" : "App-mappe finnes allerede",
    "Can't create app folder. Please fix permissions. %s" : "Kan ikke opprette app-mappe.  Vennligst ordne opp i tillatelser. %s",
    "Archive does not contain a directory named %s" : "Arkivet inneholder ikke en mappe med navn %s",
    "No source specified when installing app" : "Ingen kilde spesifisert ved installering av app",
    "No href specified when installing app from http" : "Ingen href spesifisert ved installering av app fra http",
    "No path specified when installing app from local file" : "Ingen sti spesifisert ved installering av app fra lokal fil",
    "Archives of type %s are not supported" : "Arkiver av type %s støttes ikke",
    "Failed to open archive when installing app" : "Klarte ikke å åpne arkiv ved installering av app",
    "App does not provide an info.xml file" : "App-en inneholder ikke filen info.xml",
    "App cannot be installed because appinfo file cannot be read." : "App kan ikke installeres på grunn av at appinfo filen ikke kan leses.",
    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Signatur kunne ikke sjekkes. Kontakt app-utvikleren og sjekk admin-bildet.",
    "App can't be installed because of not allowed code in the App" : "App kan ikke installeres på grunn av ulovlig kode i appen.",
    "App can't be installed because it is not compatible with this version of the server" : "Appen kan ikke installere fordi den ikke er kompatibel med denne tjenerversjonen.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "App kan ikke installeres fordi den er merket med <shipped>true</shipped> som ikke er tillatt for apper som ikke leveres med systemet",
    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "App kan ikke installeres fordi versjonen i info.xml ikke er den samme som versjonen som rapporteres fra app-butikken",
    "Logging" : "Logging",
    "Recommended" : "Anbefalt",
    "Microsoft Windows Platform is not supported" : "Microsoft Windows-plattform støttes ikke",
    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself." : "Kjøring av Nextcloud tjeneren på en Microsoft Windows plattform er ikke støttet. Vi foreslår at du bruker en Linux tjener i en virtuell maskin hvis du ikke har mulighet til å migrere tjeneren selv.",
    "Storage not available" : "Lagringsplass ikke tilgjengelig",
    "ownCloud %s or higher is required." : "Nextcloud %s eller høyere er påkrevd.",
    "ownCloud %s or lower is required." : "Nextcloud %s eller lavere er påkrevd.",
    "App \"%s\" cannot be installed because it is not compatible with this version of Nextcloud." : "Appen \"%s\" kan ikke installeres da den ikke er kompatibel med denne versjonen av Nextcloud",
    "App can't be installed because it is not compatible with this version of Nextcloud" : "Appen kan ikke installeres da den ikke er kompatibel med denne versjonen av Nextcloud",
    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "App kan ikke installeres fordi versjonen i info.xml/version ikke er den samme som versjonen som rapporteres fra app-butikken",
    "Hint: You can speed up the upgrade by executing this SQL command manually: ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;" : "Hint: Du kan øke hastigheten på oppgraderingen ved å kjøre denne SQL kommandoen manuelt: ALTER TABLE %s ADD COLUMN checksum varchar(255) DEFAULT NULL AFTER permissions;",
    "Running Nextcloud Server on the Microsoft Windows platform is not supported. We suggest you use a Linux server in a virtual machine if you have no option for migrating the server itself. Find Linux packages as well as easy to deploy virtual machine images on <a href=\"%s\">%s</a>. For migrating existing installations to Linux you can find some tips and a migration script in <a href=\"%s\">our documentation</a>." : "Kjøring av Nextcloud tjeneren på en Microsoft Windows plattform er ikke støttet. Vi foreslår at du bruker en Linux tjener i en virtuell maskin hvis du ikke har mulighet til å migrere selve tjeneren. Finn Linuxpakker og virtuelle maskiner på <a href=\"%s\">%s</a>. For å migrere eksisterende installasjon til Linux kan du finne gode tips og migreringsskript i vår <a href=\"%s\">dokumentasjon</a>.",
    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Dette fikses vanligvis ved å <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">gi webtjeneren skrivetilgang til rotmappen</a>."
},
"nplurals=2; plural=(n != 1);");
